==> cscec5b-fjwz-api-3.0.1-20221130.061341-12-sources.jar: com/ejianc/business/fjwz/vo/InviteDetailVO.java <==
package com.ejianc.business.fjwz.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 询价立项-子表
 * 
 * @author generator
 * 
 */
@ApiModel("询价立项-子表")
public class InviteDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("招标主键ID")
    private Long inviteId;
    @ApiModelProperty("材料ID")
    private Long materialId;
    @ApiModelProperty("材料来源ID")
    private String materialSourceId;
    @ApiModelProperty("材料名称")
    private String materialName;
    @ApiModelProperty("材料编码")
    private String materialCode;
    @ApiModelProperty("材料分类ID")
    private Long materialTypeId;
    @ApiModelProperty("材料分类名称")
    private String materialTypeName;
    @ApiModelProperty("单位")
    private String unit;
    @ApiModelProperty("")
    private String spec;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("申请处置数量")
    private BigDecimal applyNum;
    @ApiModelProperty("剩余可处置数量")
    private BigDecimal surplusNum;
    @ApiModelProperty("询价数量")
    private BigDecimal tenderNum;
    @ApiModelProperty("出厂数量")
    private BigDecimal outNum;

    @ApiModelProperty("询价公告-按材料查看报价使用")
    private List<DocumentSellVO> documentSupplierSellList = new ArrayList<>();

    public BigDecimal getOutNum() {
        return outNum;
    }

    public void setOutNum(BigDecimal outNum) {
        this.outNum = outNum;
    }

    public List<DocumentSellVO> getDocumentSupplierSellList() {
        return documentSupplierSellList;
    }

    public void setDocumentSupplierSellList(List<DocumentSellVO> documentSupplierSellList) {
        this.documentSupplierSellList = documentSupplierSellList;
    }

    /**
     * 招标主键ID
     */
    public Long getInviteId() {
        return inviteId;
    }

    /**
     * 招标主键ID
     */
    public void setInviteId(Long inviteId) {
        this.inviteId = inviteId;
    }
    /**
     * 材料ID
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 材料ID
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 材料来源ID
     */
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 材料来源ID
     */
    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 材料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 材料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 材料分类ID
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 材料分类ID
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 材料分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 材料分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 申请处置数量
     */
    public BigDecimal getApplyNum() {
        return applyNum;
    }

    /**
     * 申请处置数量
     */
    public void setApplyNum(BigDecimal applyNum) {
        this.applyNum = applyNum;
    }
    /**
     * 剩余可处置数量
     */
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    /**
     * 剩余可处置数量
     */
    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    /**
     * 询价数量
     */
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    /**
     * 询价数量
     */
    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    
}

==> cscec5b-fjwz-api-3.0.1-20221213.083836-44-sources.jar: com/ejianc/business/fjwz/vo/InviteDetailVO.java <==
package com.ejianc.business.fjwz.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 询价立项-子表
 * 
 * @author generator
 * 
 */
@ApiModel("询价立项-子表")
public class InviteDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("招标主键ID")
    private Long inviteId;
    @ApiModelProperty("材料ID")
    private Long materialId;
    @ApiModelProperty("材料来源ID")
    private String materialSourceId;
    @ApiModelProperty("材料名称")
    private String materialName;
    @ApiModelProperty("材料编码")
    private String materialCode;
    @ApiModelProperty("材料分类ID")
    private Long materialTypeId;
    @ApiModelProperty("材料分类名称")
    private String materialTypeName;
    @ApiModelProperty("单位")
    private String unit;
    @ApiModelProperty("")
    private String spec;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("申请处置数量")
    private BigDecimal applyNum;
    @ApiModelProperty("剩余可处置数量")
    private BigDecimal surplusNum;
    @ApiModelProperty("询价数量")
    private BigDecimal tenderNum;
    @ApiModelProperty("出厂数量")
    private BigDecimal outNum;
    @TableField(value="unit_id")
    private String unitId; //单位id

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    @ApiModelProperty("询价公告-按材料查看报价使用")
    private List<DocumentSellVO> documentSupplierSellList = new ArrayList<>();

    public BigDecimal getOutNum() {
        return outNum;
    }

    public void setOutNum(BigDecimal outNum) {
        this.outNum = outNum;
    }

    public List<DocumentSellVO> getDocumentSupplierSellList() {
        return documentSupplierSellList;
    }

    public void setDocumentSupplierSellList(List<DocumentSellVO> documentSupplierSellList) {
        this.documentSupplierSellList = documentSupplierSellList;
    }

    /**
     * 招标主键ID
     */
    public Long getInviteId() {
        return inviteId;
    }

    /**
     * 招标主键ID
     */
    public void setInviteId(Long inviteId) {
        this.inviteId = inviteId;
    }
    /**
     * 材料ID
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 材料ID
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 材料来源ID
     */
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 材料来源ID
     */
    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 材料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 材料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 材料分类ID
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 材料分类ID
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 材料分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 材料分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 申请处置数量
     */
    public BigDecimal getApplyNum() {
        return applyNum;
    }

    /**
     * 申请处置数量
     */
    public void setApplyNum(BigDecimal applyNum) {
        this.applyNum = applyNum;
    }
    /**
     * 剩余可处置数量
     */
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    /**
     * 剩余可处置数量
     */
    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    /**
     * 询价数量
     */
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    /**
     * 询价数量
     */
    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    
}
